pub type IfOwnedBy<AccountId, Inner = NoParams> = CheckState<Owner<AccountId>, Inner>;Expand description
The operation implementation must check if the given account owns the asset and act according to the inner strategy.
Aliased Type
struct IfOwnedBy<AccountId, Inner = NoParams>(pub AccountId, pub Inner);Fields
0: AccountId1: Inner