pub type PredefinedId<Id> = DeriveAndReportId<Id, Id>;Expand description
The PredefinedId is an ID assignment approach intended to be used in
"create" strategies.
It accepts the Id that should be assigned to the newly created asset.
The “create” strategy should report the Id value upon successful asset creation.
Aliased Type
struct PredefinedId<Id> {
pub params: Id,
/* private fields */
}Fields
params: Id